==> haskell-aeson-casing-0.2.0.0-216-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-casing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-casing
version:              0.2.0.0
visibility:           public
id:                   aeson-casing-0.2.0.0-9KbBeP3fItI2MmF2ZxOdJA
key:                  aeson-casing-0.2.0.0-9KbBeP3fItI2MmF2ZxOdJA
license:              MIT
maintainer:           andrewrademacher@gmail.com
author:               Andrew Rademacher
synopsis:
    Tools to change the formatting of field names in Aeson
    instances.

description:
    Tools to change the formatting of field names in Aeson
    instances. This includes CamelCasing, Pascal Casing and
    Snake Casing.

category:             Data
abi:                  f2dfe8c30905bdd724b09a0713ba3c54
exposed:              True
exposed-modules:      Data.Aeson.Casing Data.Aeson.Casing.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-casing
hs-libraries:         HSaeson-casing-0.2.0.0-9KbBeP3fItI2MmF2ZxOdJA
depends:              aeson-2.1.2.1-FLNpA1kYfSp7ISjZQSk2AY base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-aeson-casing/html/aeson-casing.haddock

haddock-html:         /usr/share/doc/haskell-aeson-casing/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-casing-0.2.0.0-217-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-casing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-casing
version:              0.2.0.0
visibility:           public
id:                   aeson-casing-0.2.0.0-ImiPICjGt9k4RVJqdXolFF
key:                  aeson-casing-0.2.0.0-ImiPICjGt9k4RVJqdXolFF
license:              MIT
maintainer:           andrewrademacher@gmail.com
author:               Andrew Rademacher
synopsis:
    Tools to change the formatting of field names in Aeson
    instances.

description:
    Tools to change the formatting of field names in Aeson
    instances. This includes CamelCasing, Pascal Casing and
    Snake Casing.

category:             Data
abi:                  fbc4a7efd0800eba9cbebcf25b7854ba
exposed:              True
exposed-modules:      Data.Aeson.Casing Data.Aeson.Casing.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-casing
hs-libraries:         HSaeson-casing-0.2.0.0-ImiPICjGt9k4RVJqdXolFF
depends:              aeson-2.1.2.1-AErwMfn2r5g1Pc6FekWoJb base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-aeson-casing/html/aeson-casing.haddock

haddock-html:         /usr/share/doc/haskell-aeson-casing/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
